textblob-de — textblob-de 0.4.3 documentation

# textblob-de

Release 0.4.3 (Changelog)

TextBlob is a Python (2 and 3) library for processing textual data. It is being developed by Steven Loria. It provides a simple API for diving into common natural language processing (NLP) tasks such as part-of-speech tagging, noun phrase extraction, sentiment analysis, classification, translation, and more.

`textblob-de` is the German language extension for TextBlob.

    from textblob_de import TextBlobDE

    text = '''
    "Der Blob" macht in seiner unbekümmert-naiven Weise einfach nur Spass.
    Er hat eben den gewissen Charme, bei dem auch die eher hölzerne Regie und
    das konfuse Drehbuch nicht weiter stören.
    '''

    blob = TextBlobDE(text)
    blob.tags           # [('Der', 'DT'), ('Blob', 'NN'), ('macht', 'VB'),
                        #  ('in', 'IN'), ('seiner', 'PRP$'), ...]

    blob.noun_phrases   # WordList(['Der Blob', 'seiner unbekümmert-naiven Weise',
                        #           'den gewissen Charme', 'hölzerne Regie',
                        #           'konfuse Drehbuch'])

    for sentence in blob.sentences:
        print(sentence.sentiment.polarity)
    # 1.0
    # 0.0

    blob.translate(to="es")  # '" The Blob " hace a su manera ingenua...'

For a complete overview of TextBlob ‘s features, see documentation of the main TextBlob library.

The docs of the German language extension focus on additions/differences to TextBlob and provide a detailed API reference.

# Guide

- textblob-de README
  - Features
  - Installing/Upgrading
  - Usage
  - Access to `pattern` API in Python3
  - Documentation and API Reference
  - Requirements
  - TODO
  - License
  - Thanks
- Tutorial: Quickstart
- Advanced Usage: Overriding Models and the Blobber Class
- Extensions
- API Reference
  - Blob Classes
  - Base Classes
  - Tokenizers
  - POS Taggers
  - Noun Phrase Extractors
  - Sentiment Analyzers
  - Parsers
  - Classifiers (from TextBlob main package)
  - Blobber
  - File Formats (from TextBlob main package)
  - Exceptions (from TextBlob main package)

# Project info

- Changelog
- Credits
- LICENSE
- Contributing guidelines
- `make` command
- Project `Makefile`
- Documentation `Makefile`